@@ -1,9 +1,9 @@
-# $Rev: 649 $
+# $Rev: 679 $
 package Date::ICal;
 use strict;
 
 use vars qw($VERSION $localzone $localoffset @months @leapmonths %add_units);
-$VERSION = '2.'.(qw'$Rev: 649 $')[1];
+$VERSION = '2.'.(qw'$Rev: 679 $')[1];
 use Carp;
 use Time::Local;
 use Date::Leapyear qw();
@@ -24,7 +24,7 @@ Date::ICal - Perl extension for ICalendar date objects.
 
 =head1 VERSION
 
-$Revision: 649 $
+$Revision: 679 $
 
 =head1 SYNOPSIS
 
@@ -49,8 +49,8 @@ Date::ICal::Duration (qv) object.
 
     $ical += 'P6DT12H';
 
-    $duration = $ical1 - $ical2;
-    $ical3 = $ical1 - $duration;
+    $duration = $ical - $ical2;
+    $ical3 = $ical - $duration;
 
 =head1 DESCRIPTION
 
@@ -334,7 +334,7 @@ sub epoch {
 
         $epoch =
           timegm( $self->sec, $self->min, $self->hour, $self->day,
-          ( $self->month ) - 1, ( $self->year ) - 1900 );
+          ( $self->month ) - 1, $self->year );
     }
 
     return $epoch;
@@ -500,7 +500,7 @@ sub offset {
 =head2 add
 
     $self->add( year => 3, month => 2, week => 1, day => 12,
-                hour => 1, minute => 34, sec => 59 );
+                hour => 1, min => 34, sec => 59 );
     $date->add( duration => 'P1WT1H1M1S' ); # add 1 wk, 1 hr, 1 min, and 1 sec
 
 Adds a duration to a Date::ICal object.
@@ -512,7 +512,7 @@ hour, min, sec or seconds.
 
 If a value is undefined or omitted, 1 is assumed:
 
-    $ical->add( 'minute' ); # add a minute
+    $ical->add( 'min' ); # add a minute
 
 The result will be normalized. That is, the output time will have
 meaningful values, rather than being 48:73 pm on the 34th of 
@@ -815,9 +815,9 @@ sub subtract {
     # we should subtract and get a date
         return $date1 - $dur; # Is that cheating?
 
-    # Otherwise, we should call them nasty names and return undef
+    # Otherwise, return undef
     } else {
-        warn "Moron";
+        warn "Invalid arguments. You can subtract a date from a date, or a duration from a date";
         return;
     }
 
